% --------------------------STATE EQUATIONS-------------------------- 

function dxdt=IMabcf0(t,x,Rs,Rr,Lm, Lsl,Lrl, p, Vs ,wo,J,Bm,TLi,TLf)

  % ---------------------- INPUTS -----------------------------------------     
  %  Load profile :    
        
  if t<1.5, TL=TLi;
        elseif t>=1.5 & t<5, TL=TLf;  
        elseif t>5, TL=TLi;    
  end    
  %  Stator voltage profile  :  
   gam=2*pi/3;
   vas=Vs*cos(wo*t);    vbs=Vs*cos(wo*t-gam);  vcs=Vs*cos(wo*t+gam);
  % ------------------------------------------------------------------------
                          % State variable vector
                    % x=[ias ibs ics iar ibr icr wm theta]'
   Lm1=2/3*Lm;      % single phase inductance                 
   Ls=Lsl+Lm1; Lr=Lrl+Lm1;      
  wm=x(7) ;  % speed [electrical rad/s]
  theta=x(8);% angular displacement between stator as_axis and rotor ar_axis [rad]
 
    V=[vas vbs vcs 0 0 0]';                    % Voltage vector
    I=x(1:6) ;                                 % Current vector
    
    R=diag([Rs Rs Rs Rr Rr Rr]);               % Resistance matrix   
    
   % Inductance matrices :
    Lss=[Ls   -Lm1/2 -Lm1/2   
        -Lm1/2   Ls  -Lm1/2
        -Lm1/2 -Lm1/2   Ls];  
    
    Lrr=[Lr   -Lm1/2 -Lm1/2   
        -Lm1/2   Lr  -Lm1/2
        -Lm1/2 -Lm1/2   Lr]; 
    
    Lsr=Lm1*[cos(theta)     cos(theta+gam) cos(theta-gam)
            cos(theta-gam)   cos(theta)   cos(theta+gam)
            cos(theta+gam) cos(theta-gam)     cos(theta)];
    
    dLsr=Lm1*[-sin(theta)     -sin(theta+gam) -sin(theta-gam)
            -sin(theta-gam)   -sin(theta)    -sin(theta+gam)
            -sin(theta+gam)  -sin(theta-gam)     -sin(theta)];
              
       
    L=[Lss  Lsr                     
       Lsr' Lrr];                   % Inductance matrix
       
    dLdtheta=[zeros(3) dLsr         
               dLsr'  zeros(3)];    % dL/dtheta
                   
        
    Te=p/4*I'*dLdtheta*I ;          % Electromagnetic torque
 
  %%% Matrix formulation of induction machine equations in abc stationary reference frame| 
  %%% Constitutive flux-current relations:
  %%%    F = L*I   or  I = L\F  
  %%% Electrical system equations:
  %%%    V= R*I + dF/dt = R*I + d(L*I)/dt = (R + wm*dL/dtheta)*I + L*dI/dt  
  %%% Mechanical system equation:
  %%%    Te = J*dwm/dt + TL + Bm*wm
    
   didt=L\(V-(R+wm*dLdtheta)*I);                  % Electrical system equations
   dwmdt=p/2*(Te-TL)/J-Bm*wm/J; dthetadt=wm;      % Mechanical system equations
   
   dxdt=[didt;dwmdt;dthetadt];                    % State equations arrived at by concatenation
   
 %%% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  